InternalError

Enum InternalError 

pub(crate) enum InternalError {
    PointDecompression,
    ScalarFormat,
    BytesLength {
        name: &'static str,
        length: usize,
    },
    Verify,
    MismatchedKeypair,
}
Internal errors. Most application-level developers will likely not need to pay any attention to these.

Variants



PointDecompression



ScalarFormat



BytesLength

An error in the length of bytes handed to a constructor.

To use this, pass a string specifying the name of the type which is returning the error, and the length in bytes which its constructor expects.

Fields

name: &'static str
length: usize


Verify

The verification equation wasn’t satisfied



MismatchedKeypair

A mismatched (public, secret) key pair.